@@ -1,11 +1,12 @@
 var indexSectionsWithContent =
 {
-  0: "abcdgilmoprs",
+  0: "%abcdgilmoprs",
   1: "l",
   2: "o",
   3: "abcdgimprs",
   4: "dl",
-  5: "l"
+  5: "l",
+  6: "%"
 };
 
 var indexSectionNames =
@@ -15,7 +16,8 @@ var indexSectionNames =
   2: "namespaces",
   3: "functions",
   4: "variables",
-  5: "groups"
+  5: "groups",
+  6: "pages"
 };
 
 var indexSectionLabels =
@@ -25,6 +27,7 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Functions",
   4: "Variables",
-  5: "Modules"
+  5: "Modules",
+  6: "Pages"
 };
 
